==> sqlitestudio-3.1.1.tar.gz: SQLiteStudio3/sqlitestudio/translations/sqlitestudio_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="44"/>
        <source>GUI interface to SQLiteStudio, a SQLite manager.</source>
        <translatorcomment>Interface GUI de SQLiteStudio un outil pour SQLite</translatorcomment>
        <translation></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="48"/>
        <source>Enables debug messages in console (accessible with F12).</source>
        <translation>Messages de déboguage avec la console(accessible avec F12).</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="49"/>
        <source>Redirects debug messages into standard output (forces debug mode).</source>
        <translation>Messages de déboguage redirigés vers sortie standard(mode déboguage forcé).</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>Redirects debug messages into given file (forces debug mode).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>log file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>Enables Lemon parser debug messages for SQL code assistant.</source>
        <translation>Message de déboguage avec l’analyseur Lemon pour un assistant code SQL.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>Enables debugging of every single SQL query being sent to any database.</source>
        <translation>Déboguage pour toutes requêtes SQL simple utilisé pour la plupart des bases de données.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Limits SQL query messages to only the given &lt;database&gt;.</source>
        <translation>Limites des meesages de la requête SQL pour la &lt;database&gt;.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>database</source>
        <translation>Base de données</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>Enables debugging of SQLiteStudio&apos;s query executor.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="55"/>
        <source>Lists plugins installed in the SQLiteStudio and quits.</source>
        <translation>Listes des plugins installés dans SQLiteStudio et quitter.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="56"/>
        <source>Points to the master configuration file. Read manual at wiki page for more details.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="56"/>
        <source>SQLiteStudio settings file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>file</source>
        <translation>Fichier</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>Database file to open</source>
        <translation>Fichier de la base de données à ouvrir</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="94"/>
        <location filename="../main.cpp" line="110"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
</context>
</TS>

==> sqlitestudio-3.2.1.tar.gz: SQLiteStudio3/sqlitestudio/translations/sqlitestudio_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="49"/>
        <source>GUI interface to SQLiteStudio, a SQLite manager.</source>
        <translation>Interface GUI de SQLiteStudio, un outil pour SQLite.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Enables debug messages in console (accessible with F12).</source>
        <translation>Messages de déboguage dans la console (accessible avec F12).</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>Redirects debug messages into standard output (forces debug mode).</source>
        <translation>Messages de déboguage redirigés vers sortie standard (mode déboguage forcé).</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="55"/>
        <source>Redirects debug messages into given file (forces debug mode).</source>
        <translation>Messages de déboguage redirigés vers un fichier (mode déboguage forcé).</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="55"/>
        <source>log file</source>
        <translation>fichier log</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="56"/>
        <source>Enables Lemon parser debug messages for SQL code assistant.</source>
        <translation>Message de déboguage avec l’analyseur Lemon pour un assistant code SQL.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="57"/>
        <source>Enables debugging of every single SQL query being sent to any database.</source>
        <translation>Déboguage pour chaque requête SQL envoyée à toute base de données.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>Limits SQL query messages to only the given &lt;database&gt;.</source>
        <translation>Limite les messages de la requête SQL à la &lt;database&gt;.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>database</source>
        <translation>Base de données</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="59"/>
        <source>Enables debugging of SQLiteStudio&apos;s query executor.</source>
        <translation>Déboguage de l&apos;exécuteur de requêtes de SQLiteStudio.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="60"/>
        <source>Lists plugins installed in the SQLiteStudio and quits.</source>
        <translation>Liste les plugins installés dans SQLiteStudio et quitte.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>Points to the master configuration file. Read manual at wiki page for more details.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>SQLiteStudio settings file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>file</source>
        <translation>Fichier</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>Database file to open</source>
        <translation>Fichier de la base de données à ouvrir</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="vanished">Erreur</translation>
    </message>
</context>
</TS>
